@@ -1,6 +1,6 @@
 package Authen::NZigovt;
 BEGIN {
-  $Authen::NZigovt::VERSION = '1.02';
+  $Authen::NZigovt::VERSION = '1.04';
 }
 
 use warnings;
@@ -138,9 +138,10 @@ sub _dispatch_make_bundle {
 sub _dispatch_make_req {
     my($class, $opt) = @_;
 
+    my $allow_create = $opt->{allow_create} ? 1 : 0;
     my $sp  = $class->service_provider( conf_dir => _conf_dir($opt) );
     my $req = $sp->new_request(
-        allow_create => 0,
+        allow_create => $allow_create,
     );
     print "Request ID: ", $req->request_id, "\n" if -t 1;
     print $req->as_url, "\n";
@@ -181,6 +182,11 @@ sub _dispatch_resolve {
 }
 
 
+sub _dispatch_version {
+    print $Authen::NZigovt::VERSION, "\n";
+}
+
+
 sub _conf_dir {
     my($opt) = @_;
 
